@@ -583,6 +583,7 @@ rcube_webmail.prototype.sieverules_action_select = function(sel) {
 	document.getElementsByName('_imapflags[]')[idx].style.display = 'none';
 	document.getElementsByName('_day[]')[idx].parentNode.parentNode.parentNode.parentNode.style.display = 'none';
 	document.getElementsByName('_nmethod[]')[idx].parentNode.parentNode.parentNode.parentNode.style.display = 'none';
+	document.getElementsByName('_eheadname[]')[idx].parentNode.parentNode.parentNode.parentNode.style.display = 'none';
 
 	if (obj.value == 'fileinto' || obj.value == 'fileinto_copy')
 		document.getElementsByName('_folder[]')[idx].style.display = '';
@@ -605,6 +606,22 @@ rcube_webmail.prototype.sieverules_action_select = function(sel) {
 		document.getElementsByName('_redirect[]')[idx].style.display = '';
 	else if (obj.value == 'imapflags' || obj.value == 'imap4flags')
 		document.getElementsByName('_imapflags[]')[idx].style.display = '';
+	else if (obj.value == 'editheaderadd' || obj.value == 'editheaderrem') {
+		document.getElementsByName('_eheadname[]')[idx].parentNode.parentNode.parentNode.parentNode.style.display = '';
+
+		if (obj.value == 'editheaderrem') {
+			document.getElementsByName('_eheadval[]')[idx].parentNode.parentNode.style.display = 'none';
+			document.getElementsByName('_eheadaddlast[]')[idx].parentNode.parentNode.style.display = 'none';
+			document.getElementsByName('_hadv_opts[]')[idx].parentNode.parentNode.style.display = '';
+		}
+		else {
+			document.getElementsByName('_eheadval[]')[idx].parentNode.parentNode.style.display = '';
+			document.getElementsByName('_eheadaddlast[]')[idx].parentNode.parentNode.style.display = '';
+			document.getElementsByName('_eheadopp[]')[idx].parentNode.parentNode.style.display = 'none';
+			document.getElementsByName('_eheadindex[]')[idx].parentNode.parentNode.style.display = 'none';
+			document.getElementsByName('_hadv_opts[]')[idx].parentNode.parentNode.style.display = 'none';
+		}
+	}
 
 	if ($(document.getElementsByName('_folder[]')[idx]).is(':visible') && document.getElementsByName('_folder[]')[idx].value == '@@newfolder')
 		$(document.getElementsByName('_customfolder[]')[idx]).parent().show();
@@ -810,6 +827,15 @@ rcube_webmail.prototype.enable_sig = function(obj) {
 		rcmail.enable_command('plugin.sieverules.vacation_sig', false);
 }
 
+rcube_webmail.prototype.sieverules_toggle_eheadlast = function(obj) {
+	var selectobj = document.getElementById(obj.id.replace('_eheadaddlast_', '_eheadindex_'));
+
+	if (obj.checked)
+		selectobj.selectedIndex = 6;
+	else
+		selectobj.selectedIndex = 0;
+}
+
 $(document).ready(function() {
 	if (window.rcmail) {
 		rcmail.addEventListener('init', function(evt) {
@@ -1141,6 +1167,8 @@ $(document).ready(function() {
 					var msgs = document.getElementsByName('_msg[]');
 					var nmethods = document.getElementsByName('_nmethod[]');
 					var nmsgs = document.getElementsByName('_nmsg[]');
+					var eheadernames = document.getElementsByName('_eheadname[]');
+					var eheadervals = document.getElementsByName('_eheadval[]');
 					var size_test = new RegExp('^[0-9]+$');
 					var spamtest_test = new RegExp('^[0-9]+$');
 					var header_test = new RegExp('^[a-zA-Z0-9\-]+( ?, ?[a-zA-Z0-9\-]+)*$');
@@ -1216,12 +1244,12 @@ $(document).ready(function() {
 							if (dateparts[i].value == 'date' && !date_test.test(targets[i].value)) {
 								alert(rcmail.gettext('baddateformat','sieverules'));
 								targets[i].focus();
-								return false
+								return false;
 							}
 							else if (dateparts[i].value == 'time' && !time_test.test(targets[i].value)) {
 								alert(rcmail.gettext('badtimeformat','sieverules'));
 								targets[i].focus();
-								return false
+								return false;
 							}
 						}
 					}
@@ -1257,7 +1285,7 @@ $(document).ready(function() {
 							}
 						}
 						else if (acts[i][idx].value == 'vacation') {
-							if (senders[i].value != '' && senders[i].value != 'auto' && !rcube_check_email(senders[i].value.replace(/^\s+/, '').replace(/[\s,;]+$/, ''), true)) {
+							if (senders[i].value != '' && senders[i].value != 'auto' && !rcube_check_email(senders[i].value.replace(/^\s+/, '').replace(/[\s,;]+$/, ''), true) && !$.isNumeric(senders[i].value)) {
 								alert(rcmail.gettext('redirectaddresserror','sieverules'));
 								senders[i].focus();
 								return false;
@@ -1287,7 +1315,8 @@ $(document).ready(function() {
 							//	return false;
 							//}
 
-							if (msgs[i].value == '') {
+							var editor = tinyMCE.get("rcmfd_sievevacmag_" + (i - 1));
+							if ((editor && editor.getContent() == '') || (!editor && msgs[i].value == '')) {
 								alert(rcmail.gettext('vacnomsg','sieverules'));
 								msgs[i].focus();
 								return false;
@@ -1312,6 +1341,21 @@ $(document).ready(function() {
 								return false;
 							}
 						}
+						else if (acts[i][idx].value == 'editheaderadd' || acts[i][idx].value == 'editheaderrem') {
+							if (eheadernames[i].value == '') {
+								alert(rcmail.gettext('eheadernoname','sieverules'));
+								eheadernames[i].focus();
+								return false;
+							}
+
+							if (acts[i][idx].value == 'editheaderadd') {
+								if (eheadervals[i].value == '') {
+									alert(rcmail.gettext('eheadernoval','sieverules'));
+									eheadervals[i].focus();
+									return false;
+								}
+							}
+						}
 					}
 
 					// enable the comparators field
